AlwaysLogging = LibStub("AceAddon-3.0"):NewAddon("AlwaysLogging", "AceConsole-3.0")

--[[
As of November 28th. 2020
Retail: 90002
Classic: 11305
]]

local GameVersion = "RETAIL"
local L = LibStub("AceLocale-3.0"):GetLocale("AlwaysLogging", true)
local FullPlayerName = (GetUnitName("PLAYER", false) .. "-" .. string.gsub(string.gsub(GetRealmName(), "-", ""), "%s+", ""))
local e = {}

if GetClientDisplayExpansionLevel() < 7 then
	GLR_GameVersion = "CLASSIC"
end

local function FormatNumber(n)
	if n ~= nil then
		if n < 10 then
			n = "0" .. tostring(n)
		end
		return n
	else return "NA" end
end

local function GetTimeStamp()
	local t = GetServerTime()
	if t ~= nil then
		local d = date("*t", t)
		d.month = FormatNumber(d.month)
		d.day = FormatNumber(d.day)
		d.year = FormatNumber(d.year)
		d.hour = FormatNumber(d.hour)
		d.min = FormatNumber(d.min)
		d.sec = FormatNumber(d.sec)
		local s = d.month .. "/" .. d.day .. "/" .. d.year .. " - " .. d.hour .. ":" .. d.min .. "." .. d.sec
		return s
	else
		return "NA"
	end
end

local function CheckLogStatus()
	if AlwaysLoggingData[FullPlayerName] then
		if not LoggingCombat() then
			LoggingCombat(true)
			AlwaysLogging:Print(L["Combat Log Enabled"])
			C_Timer.After(60, CheckLogStatus)
		else
			C_Timer.After(60, CheckLogStatus)
		end
	else
		if LoggingCombat() then
			LoggingCombat(false)
			AlwaysLogging:Print(L["Combat Log Disabled"])
		end
	end
end

function AlwaysLogging:OnInitialize()
	
	if AlwaysLoggingData == nil then
		AlwaysLoggingData = {}
	end
	
	if AlwaysLoggingData[FullPlayerName] == nil then
		AlwaysLoggingData[FullPlayerName] = true
	elseif AlwaysLoggingData[FullPlayerName] then
		CheckLogStatus()
	end
	
	if AlwaysLoggingData.Log == nil then
		AlwaysLoggingData.Log = {}
	end
	
	if AlwaysLoggingData.Log[FullPlayerName] == nil then
		AlwaysLoggingData.Log[FullPlayerName] = {}
	end
	
	local options = {
		name = L["Options"],
		handler = self,
		type = "group",
		childGroups = "tab",
		args = {
			author = {
				order = 1,
				type = "description",
				name = "|cFFFFE300" .. L["Author"] .. "|r Tempuseteri-Area52",
				width = "full",
			},
			translators = {
				order = 2,
				type = "description",
				name = "|cFFFFE300" .. L["Translators"] .. "|r Projetisthename (French)",
				width = "full",
			},
			enable = {
				order = 3,
				type = "toggle",
				name = L["Enable"],
				desc = L["Enable Desc"],
				width = "double",
				get = function()
					return AlwaysLoggingData[FullPlayerName]
				end,
				set = function(info, val)
					AlwaysLoggingData[FullPlayerName] = val
					if val then
						AlwaysLogging:Print(L["Log Enabled Msg"])
					elseif not val then
						AlwaysLogging:Print(L["Log Disabled Msg"])
					end
					CheckLogStatus()
				end,
			}
		}
	}
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("AlwaysLogging", options)
	alwaysloggingOptions = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("AlwaysLogging", "Always Logging")
end